@@ -264,7 +264,7 @@ class Spec(object):
 		:param func msg_func:
 			Callable like ``msg_func`` from :py:meth:`Spec.check_func`. Should 
 			accept one problematic item and is not used for :py:class:`Spec` 
-			object indicies in ``item_func`` method.
+			object indices in ``item_func`` method.
 
 		:return: proceed, hadproblem.
 		'''
@@ -515,7 +515,7 @@ class Spec(object):
 			optional. Each element in this list describes element with the same 
 			index in the checked value. Check out :py:meth:`Spec.check_tuple` 
 			for more details, but note that there list of specifications is 
-			replaced with start and end indicies in ``self.specs``.
+			replaced with start and end indices in ``self.specs``.
 
 		:return: self.
 		'''
@@ -633,7 +633,7 @@ class Spec(object):
 
 		Check out :py:meth:`Spec.check_either` method documentation for more 
 		details, but note that there a list of specs was replaced by start and 
-		end indicies in ``self.specs``.
+		end indices in ``self.specs``.
 
 		:return: self.
 		'''
